@@ -94,6 +94,7 @@ class Fitter(object):
                    limit_fitting_mjds=False,
                    exclude_bands=[],
                    exclude_instruments=[],
+                   exclude_sources=[],
                    suffix='',
                    offline=False,
                    upload=False,
@@ -487,6 +488,7 @@ class Fitter(object):
                         limit_fitting_mjds=limit_fitting_mjds,
                         exclude_bands=exclude_bands,
                         exclude_instruments=exclude_instruments,
+                        exclude_sources=exclude_sources,
                         band_list=band_list,
                         band_systems=band_systems,
                         band_instruments=band_instruments,
@@ -547,6 +549,7 @@ class Fitter(object):
                   limit_fitting_mjds=False,
                   exclude_bands=[],
                   exclude_instruments=[],
+                  exclude_sources=[],
                   band_list=[],
                   band_systems=[],
                   band_instruments=[],
@@ -578,6 +581,7 @@ class Fitter(object):
                     limit_fitting_mjds=limit_fitting_mjds,
                     exclude_bands=exclude_bands,
                     exclude_instruments=exclude_instruments,
+                    exclude_sources=exclude_sources,
                     band_list=band_list,
                     band_systems=band_systems,
                     band_instruments=band_instruments,
