@@ -16,6 +16,7 @@ from mosfit.printer import Printer
 from mosfit.utils import listify
 # from scipy.optimize import differential_evolution
 from scipy.optimize import minimize
+# from scipy.optimize import basinhopping
 
 from astrocats.catalog.quantity import QUANTITY
 # from bayes_opt import BayesianOptimization
@@ -134,12 +135,18 @@ class Model(object):
 
         # Load model parameter file.
         model_pp = os.path.join(
-            os.path.split(model_path)[0], 'parameters.json')
+            self._dir_path, 'models', model_dir, 'parameters.json')
 
         pp = ''
 
-        selected_pp = os.path.join(
-            os.path.split(model_path)[0], parameter_path)
+        local_pp = (parameter_path if '/' in parameter_path
+                    else os.path.join('models', model_dir, parameter_path))
+
+        if os.path.isfile(local_pp):
+            selected_pp = local_pp
+        else:
+            selected_pp = os.path.join(
+                self._dir_path, 'models', model_dir, parameter_path)
 
         # First try user-specified path
         if parameter_path and os.path.isfile(parameter_path):
@@ -266,11 +273,20 @@ class Model(object):
         if not call_stack:
             call_stack = self._call_stack
         cur_task = call_stack[task]
+        kinds = self._inflect.plural(cur_task['kind'])
         mod_name = cur_task.get('class', task).lower()
-        mod = importlib.import_module(
-            '.' + 'modules.' + self._inflect.plural(
-                cur_task['kind'].lower()) + '.' + mod_name,
-            package='mosfit')
+        mod_path = os.path.join('modules', kinds, mod_name + '.py')
+        if not os.path.isfile(mod_path):
+            mod_path = os.path.join(self._dir_path, 'modules', kinds,
+                                    mod_name + '.py')
+        mod_name = 'mosfit.modules.' + kinds + mod_name
+        try:
+            mod = importlib.machinery.SourceFileLoader(mod_name,
+                                                       mod_path).load_module()
+        except AttributeError:
+            import imp
+            mod = imp.load_source(mod_name, mod_path)
+
         class_name = [
             x[0] for x in
             inspect.getmembers(mod, inspect.isclass)
@@ -402,15 +418,13 @@ class Model(object):
         #     zip(np.clip(x - step, 0.0, 1.0), np.clip(x + step, 0.0, 1.0)))
         #
         # bh = differential_evolution(
-        #     self.fprob, bounds, disp=True, polish=False, maxiter=10)
+        #     self.fprob, bounds, disp=True, polish=False)
 
-        # take_step = self.RandomDisplacementBounds(0.0, 1.0, 0.01)
         # bh = basinhopping(
         #     self.fprob,
         #     x,
         #     disp=True,
         #     niter=10,
-        #     take_step=take_step,
         #     minimizer_kwargs={'method': "L-BFGS-B",
         #                       'bounds': bounds})
 
